//////////////////////////////////////////////////////////////////////////////
// Module   : sx16.h                                                        //
// Product  : Sensoray 516/616 driver.                                      //
// Function : The sx16_ioctl() commands.                                    //
//                                                                          //
// Examples:                                                                //
//    sx16_ioctl( handle, SX16_IOC_SET_INPUT, 0 );                          //
//    sx16_ioctl( handle, SX16_IOC_RESET );                                 //
//    br = sx16_ioctl( handle, SX16_IOC_GET_SETTING, ATTR_video_bitrate );  //
//////////////////////////////////////////////////////////////////////////////

/*
NOTES:

1. These are the legal combinations for stream/mpeg modes, which are programmed via
   the SX16_IOC_SET_STREAM_TYPE and SX16_IOC_SET_MPEG ioctls:

	+------Operating mode-----+-------Settings-------+
	| Stream		Mpeg	  | STREAM_TYPE		MPEG |
	+-------------------------+----------------------+
	| Multiplexed	2:D1-704  | 	0			 0	 |
	| 	"			2:2/3 D1  | 	0			 1	 |
	| 	"			2:1/2 D1  | 	0			 2	 |
	| 	"			1:SIF	  | 	0			 3	 |
	| 	"			1:QSIF	  | 	0			 4	 |
	| 	"			2:D1-720  | 	0			 5	 |
	| 	"			2:D1-640  | 	0			 6	 |
	+-------------------------+----------------------+
	|  VES			2:D1-704  | 	1			 0	 |
	| 	"			2:2/3 D1  | 	1			 1	 |
	| 	"			2:1/2 D1  | 	1			 2	 |
	| 	"			1:SIF	  | 	1			 3	 |
	| 	"			1:QSIF	  | 	1			 4	 |
	| 	"			2:D1-720  | 	1			 5	 |
	| 	"			2:D1-640  | 	1			 6	 |
	+-------------------------+----------------------+
	+  AES			 n/a	  |		2		    n/a	 |
	+-------------------------+----------------------+

2. These are the legal combinations for i-p distance and group-of-pictures, which are programmed via the SX16_IOC_SET_N
   and SX16_IOC_SET_M ioctls; all other combinations will cause unpredictable behavior:

	N	M					GOP Format		Comments
	---------------------	--------------------------------------------------------
	1	1					iiiiiii...		i-frames only; works with NTSC and PAL.
	1	2,3,4,5, ... ,31	ipppp...		no b-frames; works with NTSC and PAL.
	2	4,6,8,10, ... ,30	ibpbpbp...		works with NTSC only.
	3	6,9,12,15, .. ,30	ibbpbbpbbp...	works with NTSC only.

*/

//===============================================================================================================
// Uncompressed capture control (616 only).

#define SX16_IOC_CAPTURE_OPEN			0x0000	// Prepare for capture.
#define SX16_IOC_CAPTURE_STATUS			0x0100	// Get capture status: returns non-zero if capture is in progress.
#define SX16_IOC_CAPTURE_START			0x0200	// Start capture.
#define SX16_IOC_CAPTURE_CLOSE			0x0300	// Stop and close capture.

//===============================================================================================================
// General-purpose I/O port.  Bit is set to 1 when the associated I/O is driven low.

#define SX16_IOC_GET_GPIO				0x1000	// Read state of GPIO pins.
#define SX16_IOC_SET_GPIO				0x1100	// Set state of GPIO pins.

//===============================================================================================================
// Video and mpeg codec configuration.

#define SX16_IOC_GET_SETTING			0x2000	// Return current configuration setting.
#define SX16_IOC_SET_AUDIO_BITRATE		0x2100	// Set audio bit rate.
#define SX16_IOC_SET_AUDIO_FORMAT		0x2110	// Set audio format: AFMT_MPEG1_LAYER1, ...
#define SX16_IOC_SET_AUDIO_MUTE			0x2120	// Enable/disable (1/0) audio mute.
#define SX16_IOC_SET_AUDIO_STEREO		0x2130	// Set stereo mode: STEREOMODE_STEREO, STEREOMODE_JOINT, STEREOMODE_DUAL or STEREOMODE_SINGLE.
#define SX16_IOC_SET_AUDIO_VOLUME		0x2140	// Set audio volume (-dB). 0=maximum, 63=minimum.
#define SX16_IOC_SET_AV_SELECT			0x2150	// Set a/v select.
#define SX16_IOC_SET_BITRATE			0x2160	// Set desired bit rate, typically 500,000 to 5,000,000.
#define SX16_IOC_SET_BRIGHTNESS			0x2170	// Set brightness for video in.
#define SX16_IOC_SET_COLORBARS			0x2180	// Enable/disable (1/0) colors bars on video out.
#define SX16_IOC_SET_CONTRAST			0x2190	// Set contrast for video in.
#define SX16_IOC_SET_FILTER				0x21a0	// Set filter for low quality input.
#define SX16_IOC_SET_INPUT				0x21b0	// Select video input, i.e. 0 - 3.
#define SX16_IOC_SET_INPUT_TYPE			0x21c0	// Set video input type, i.e. SVIDEO (1) or CVIDEO (0).
#define SX16_IOC_SET_M					0x21d0	// Set number of frames in Group of Pictures (1...15, default = 15).
#define SX16_IOC_SET_MPEG				0x21e0	// Set picture size and compression type: see note 1 above.
#define SX16_IOC_SET_N					0x21f0	// Set distance between I/P frames (1...3, default = 3).
#define SX16_IOC_SET_PROG_NUM			0x2200	// Set program number if using transport stream.
#define SX16_IOC_SET_SATURATION			0x2210	// Set saturation level for video in.
#define SX16_IOC_SET_STREAM_TYPE		0x2220	// Set stream type: STREAMTYPE_MUX (0) | STREAMTYPE_VES (1) | STREAMTYPE_AES (2).  See note 1 above.
#define SX16_IOC_SET_VBR				0x2230	// Enable/disable (1/0) variable bit rate compression.
#define SX16_IOC_SET_VIDEO_SYSTEM		0x2240	// Set input & output video system, i.e. NTSC (2) or PAL (1).

//===============================================================================================================
// Stream access and control.

#define SX16_IOC_KILL					0x3000	// Kill blocking operation.
#define SX16_IOC_RD_SENSORAY			0x3100	// Transfer encoded mpeg data (in Sensoray packetized format) to user buffer.
#define SX16_IOC_RESET					0x3200	// Reset the board.
#define SX16_IOC_RW_STOP				0x3300	// Stop read/write.
#define SX16_IOC_RW_PAUSE				0x3400	// Pause read/write.
#define SX16_IOC_RW_RESUME				0x3500	// Resume read/write after pause.

//===============================================================================================================
// Video caption overlay.

#define SX16_IOC_GET_CAPTION_SETTINGS		0x4000	// Get caption settings.
#define SX16_IOC_SET_CAPTION_WINDOW			0x4100	// Set caption window number.
#define SX16_IOC_SET_CAPTION_XSTART			0x4200	// Set caption window position: X_start.
#define SX16_IOC_SET_CAPTION_YSTART			0x4300	// Set caption window position: Y_start.
#define SX16_IOC_SET_CAPTION_SCALE			0x4400	// Set caption font scale;
#define SX16_IOC_SET_CAPTION_COLOR			0x4500	// Set caption color
#define SX16_IOC_SET_CAPTION_TRANSPARENCY	0x4600	// Set caption transparency attribute
#define SX16_IOC_SET_CAPTION_TEXT			0x4700	// Set caption text to overlay
#define SX16_IOC_SET_CAPTION_ON				0x4800	// Set caption on/off

//===============================================================================================================
// NOT RECOMMENDED FOR NEW DESIGNS--these are depracated and/or intended only for Sensoray test and diagnostics.

#define SX16_IOC_GA_LOOPBACK			0x5000	// Enable/disable video stream loopback (bypass mpeg codec).
#define SX16_IOC_GET_Q_SIZE		  		0x5100	// Get the MPEG queue size.
#define SX16_IOC_SET_MUX_FORMAT			0x5200	// Set mpeg multiplex format.
#define SX16_IOC_SET_PICSIZE			0x5300	// Set picture size and compression type.
#define SX16_IOC_SET_SYS_FORMAT			0x5400	// Set system format.  ALWAYS SET THIS TO 2.
